[![pytest](https://github.com/Deltares/dfm_tools/actions/workflows/pytest.yml/badge.svg?branch=main)](https://github.com/Deltares/dfm_tools/actions/workflows/pytest.yml)
[![codecov](https://img.shields.io/codecov/c/github/deltares/dfm_tools.svg?style=flat-square)](https://app.codecov.io/gh/deltares/dfm_tools?displayType=list)
[![Quality Gate Status](https://sonarcloud.io/api/project_badges/measure?project=Deltares_dfm_tools&metric=alert_status)](https://sonarcloud.io/summary/overall?id=Deltares_dfm_tools)
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/Deltares/dfm_tools/HEAD?urlpath=/tree/docs/notebooks)
[![Available on pypi](https://img.shields.io/pypi/v/dfm_tools.svg)](https://pypi.python.org/pypi/dfm_tools)
[![Supported versions](https://img.shields.io/pypi/pyversions/dfm_tools.svg)](https://pypi.org/project/dfm_tools)
[![Downloads](https://img.shields.io/pypi/dm/dfm_tools.svg)](https://pypistats.org/packages/dfm_tools)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.7857393.svg)](https://doi.org/10.5281/zenodo.7857393)

# dfm_tools

A Python package for pre- and postprocessing D-FlowFM model input and output files. Contains convenience functions built on top of other packages like [xarray](https://github.com/pydata/xarray), [xugrid](https://github.com/Deltares/xugrid), [hydrolib-core](https://github.com/Deltares/HYDROLIB-core) and many more.

## Information

- install with `pip install dfm_tools -U` (or [installation guide](https://deltares.github.io/dfm_tools/installation))
- [online documentation](https://deltares.github.io/dfm_tools) with installation guide, tutorials/examples, API reference and contributing guide.
- Bug or feature request? Create a [GitHub issue](https://github.com/Deltares/dfm_tools/issues)
- dfm_tools is updated regularly to keep up with all developments in packages it depends on, so make sure to update regularly. You can subscribe to dfm_tools updates via the "Watch" button of this repository (tip: only tick "Releases" to avoid spam)
